@@ -16,11 +16,9 @@ def configure_parser(parser):
     qibuild.parsers.project_parser(parser)
     group = parser.add_argument_group("make options")
     group.add_argument("--rebuild", "-r", action="store_true", default=False)
-    group.add_argument("--verbose-make", action="store_true", default=False,
-                       help="Set verbose for make. It will print the executed commands.")
     group.add_argument("--coverity", action="store_true", default=False,
                        help="Build using cov-build. Ensure you have "
-                       "cov-analisys installed on your machine.")
+                       "cov-analysis installed on your machine.")
 
 @ui.timer("qibuild make")
 def do(args):
@@ -28,4 +26,4 @@ def do(args):
 
     cmake_builder = qibuild.parsers.get_cmake_builder(args)
     cmake_builder.build(num_jobs=args.num_jobs, rebuild=args.rebuild,
-                        verbose_make=args.verbose_make, coverity=args.coverity)
+                        coverity=args.coverity)
