@@ -75,6 +75,8 @@ class GitProject(object):
 
     def update_remote(self, remote, new):
         """ Helper for configure_remote """
+        if remote == new:
+            return  # Be lazy
         if not remote.review and new.review:
             ui.info(self.src, "is now under code review")
         if remote.review and not new.review:
@@ -137,8 +139,7 @@ class GitProject(object):
             ok = qisrc.review.setup_project(self)
             if ok:
                 self.review = True
-
-        self.save_config()
+        self.apply_config()
 
 
     def sync(self, rebase_devel=False, **kwargs):
