@@ -38,6 +38,9 @@ class GitWorkTree(qisys.worktree.WorkTreeObserver):
         """ Add a new manifest to this worktree """
         self._syncer.configure_manifest(name, manifest_url, groups=groups, branch=branch)
 
+    def configure_projects(self, projects):
+        self._syncer.configure_projects(projects)
+
     def remove_manifest(self, name):
         """ Remove the given manifest from this worktree """
         self._syncer.remove_manifest(name)
@@ -185,8 +188,8 @@ class GitWorkTree(qisys.worktree.WorkTreeObserver):
         try:
             git.init()
             git.remote("add", remote_name, clone_url)
-            git.fetch(remote_name, branch, "--no-tags")
-            git.checkout("-b", branch, "FETCH_HEAD", "--quiet")
+            git.fetch(remote_name, "--quiet")
+            git.checkout("-b", branch, "%s/%s" % (remote_name, branch))
         except:
             ui.error("Cloning repo failed")
             if git.is_empty():
@@ -300,6 +303,13 @@ class GitWorkTree(qisys.worktree.WorkTreeObserver):
         self._set_elem(project.src, project_xml)
         qisys.qixml.write(self._root_xml, self.git_xml)
 
+    def save_git_config(self):
+        """ Save the worktree config in .qi/git.xml """
+        for project in self.git_projects:
+            project_xml = project.dump_xml()
+            self._set_elem(project.src, project_xml)
+        qisys.qixml.write(self._root_xml, self.git_xml)
+
     def __repr__(self):
         return "<GitWorkTree in %s>" % self.root
 
